pub trait OutgoingResponseExt: OutgoingResponse {
// Provided method
fn try_into_http_response<T>(self) -> Result<Response<T>, IntoHttpError>
where T: Default + BufMut + AsRef<[u8]> { ... }
}Available on crate feature
api only.Expand description
A request type for a Matrix API endpoint, used for sending responses.
Provided Methods
Sourcefn try_into_http_response<T>(self) -> Result<Response<T>, IntoHttpError>
fn try_into_http_response<T>(self) -> Result<Response<T>, IntoHttpError>
Tries to convert this response into an http::Response.
This method should only fail when invalid header values are specified. It may also fail with a serialization error in case of bugs in Ruma though.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".